@@ -41,8 +41,8 @@
 #include <unistd.h>
 
 
-#include "image.hpp"
-#include "exif.hpp"
+#include "exiv2/image.hpp"
+#include "exiv2/exif.hpp"
 
 #include "gpsstructure.h"
 #include "exif-gps.h"
@@ -253,6 +253,14 @@ char* ReadExifData(char* File, double* Lat, double* Long, double* Elev, int* Inc
 		GPSData = ExifRead["Exif.GPSInfo.GPSAltitude"];
 		RatNum = GPSData.toRational(0);
 		*Elev = (double)RatNum.first / (double)RatNum.second;
+
+		// Is the altitude below sea level? If so, negate the value.
+		GPSData = ExifRead["Exif.GPSInfo.GPSAltitudeRef"];
+		if (strcmp(GPSData.toString().c_str(), "1") == 0)
+		{
+			// Negate the elevation.
+			*Elev = -*Elev;
+		}
 	}
 
 
@@ -573,7 +581,8 @@ int WriteGPSData(char* File, struct GPSPoint* Point, char* Datum, int NoChangeMt
 	// If interpolation occured, then this time is the time of the photo.
 	struct tm TimeStamp;
 	TimeStamp.tm_isdst = -1;
-	gmtime_r(&(Point->Time), &TimeStamp);
+	struct tm *tmp = gmtime(&(Point->Time));
+	memcpy(&TimeStamp, tmp, sizeof(struct tm));
 	TimeStamp.tm_isdst = -1;
 
 	if (Point->Time != mktime(&TimeStamp)) {
@@ -583,7 +592,8 @@ int WriteGPSData(char* File, struct GPSPoint* Point, char* Datum, int NoChangeMt
 		// This is a hack.
 		time_t CorrectedTime = Point->Time + (Point->Time - mktime(&TimeStamp));
 
-		gmtime_r(&CorrectedTime, &TimeStamp);
+		struct tm *tmp2 = gmtime(&CorrectedTime);
+		memcpy(&TimeStamp, tmp2, sizeof(struct tm));
 	}
 
 	Value = Exiv2::Value::create(Exiv2::signedRational);
@@ -648,7 +658,8 @@ int WriteFixedDatestamp(char* File, time_t Time)
 	
 	struct tm TimeStamp;
 	TimeStamp.tm_isdst = -1;
-	gmtime_r(&Time, &TimeStamp);
+	struct tm *tmp = gmtime(&Time);
+	memcpy(&TimeStamp, tmp, sizeof(struct tm));
 	TimeStamp.tm_isdst = -1;
 
 	if (Time != mktime(&TimeStamp)) {
@@ -658,7 +669,8 @@ int WriteFixedDatestamp(char* File, time_t Time)
 		// This is a hack.
 		time_t CorrectedTime = Time + (Time - mktime(&TimeStamp));
 
-		gmtime_r(&CorrectedTime, &TimeStamp);
+		struct tm *tmp2 = gmtime(&CorrectedTime);
+		memcpy(&TimeStamp, tmp2, sizeof(struct tm));
 	}
 
 	char ScratchBuf[100];
