@@ -31,7 +31,10 @@
 #include <time.h>
 #include <getopt.h>
 #include <string.h>
-#include <termios.h>
+
+#ifndef WIN32
+  #include <termios.h>
+#endif
 
 #include "gpsstructure.h"
 #include "exif-gps.h"
@@ -190,8 +193,10 @@ void FixDatestamp(char* File, int AdjustmentHours, int AdjustmentMinutes, int No
 			}
 			char PhotoTimeFormat[100];
 			char GPSTimeFormat[100];
-			ctime_r(&PhotoTime, PhotoTimeFormat);
-			ctime_r(&GPSTime, GPSTimeFormat);
+			char *tmp = ctime(&PhotoTime);
+			strncpy(PhotoTimeFormat, tmp, 100);
+			tmp = ctime(&GPSTime);
+			strncpy(GPSTimeFormat, tmp, 100);
 			printf("%s: Wrong timestamp:\n   Photo:     %s   GPS:       %s   Corrected: %s", 
 					File, PhotoTimeFormat, GPSTimeFormat, PhotoTimeFormat);
 		} else {
@@ -280,7 +285,11 @@ int main(int argc, char** argv)
 				break;
 			case 'v':
 				/* This option asks us to show more info. */
+#ifdef WIN32
+				printf("--verbose does not work on win32\n");
+#else
 				ShowDetails = 1;
+#endif
 				break;
 			case 'd':
 				/* This option specifies a Datum, if other than WGS-84. */
@@ -488,6 +497,7 @@ int main(int argc, char** argv)
 
 	/* Twig with the terminal settings to make the single character
 	 * output stuff work right. */
+#ifndef WIN32
 	struct termios initial_settings, new_settings;
 	if (!ShowDetails)
 	{
@@ -502,7 +512,7 @@ int main(int argc, char** argv)
 			printf("Debug: Broken tty set.\n");
 		}
 	}
-	 
+#endif
 
 	/* Make it all look nice and pretty... so the user knows what's going on. */
 	printf("\nCorrelate: ");
@@ -637,11 +647,13 @@ int main(int argc, char** argv)
 	/* Right, so now we're done. That really wasn't that hard. Right? */
 
 	/* Add a new line if we were doing the not-show-details thing. */
+#ifndef WIN32
 	if (!ShowDetails)
 	{
 		printf("\n");
 		tcsetattr(fileno(stdout), TCSANOW, &initial_settings);
 	}
+#endif
 
 	/* Print details of what happenned. */
 	printf("\nCompleted correlation process.\n");
